pub struct ClaimMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on claim resources.
It is not used directly, but through the FactCheckTools hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_factchecktools1_alpha1 as factchecktools1_alpha1;
use factchecktools1_alpha1::{FactCheckTools, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = FactCheckTools::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `image_search(...)` and `search(...)`
// to build up your call.
let rb = hub.claims();Implementations
Sourceimpl<'a, C> ClaimMethods<'a, C>
impl<'a, C> ClaimMethods<'a, C>
Sourcepub fn image_search(&self) -> ClaimImageSearchCall<'a, C>
pub fn image_search(&self) -> ClaimImageSearchCall<'a, C>
Create a builder to help you perform the following task:
Search through fact-checked claims using an image as the query.
Sourcepub fn search(&self) -> ClaimSearchCall<'a, C>
pub fn search(&self) -> ClaimSearchCall<'a, C>
Create a builder to help you perform the following task:
Search through fact-checked claims.