pub struct GoogleFactcheckingFactchecktoolsV1alpha1ClaimRating {
pub best_rating: Option<i32>,
pub image_url: Option<String>,
pub rating_explanation: Option<String>,
pub rating_value: Option<i32>,
pub textual_rating: Option<String>,
pub worst_rating: Option<i32>,
}Expand description
Information about the claim rating.
This type is not used in any activity, and only used as part of another schema.
Fields
best_rating: Option<i32>For numeric ratings, the best value possible in the scale from worst to best. Corresponds to ClaimReview.reviewRating.bestRating.
image_url: Option<String>Corresponds to ClaimReview.reviewRating.image.
rating_explanation: Option<String>Corresponds to ClaimReview.reviewRating.ratingExplanation.
rating_value: Option<i32>A numeric rating of this claim, in the range worstRating — bestRating inclusive. Corresponds to ClaimReview.reviewRating.ratingValue.
textual_rating: Option<String>The truthfulness rating as a human-readible short word or phrase. Corresponds to ClaimReview.reviewRating.alternateName.
worst_rating: Option<i32>For numeric ratings, the worst value possible in the scale from worst to best. Corresponds to ClaimReview.reviewRating.worstRating.