pub struct GoogleFactcheckingFactchecktoolsV1alpha1ClaimReview {
pub language_code: Option<String>,
pub publisher: Option<GoogleFactcheckingFactchecktoolsV1alpha1Publisher>,
pub review_date: Option<DateTime<Utc>>,
pub textual_rating: Option<String>,
pub title: Option<String>,
pub url: Option<String>,
}Expand description
Information about a claim review.
This type is not used in any activity, and only used as part of another schema.
Fields
language_code: Option<String>The language this review was written in. For instance, “en” or “de”.
publisher: Option<GoogleFactcheckingFactchecktoolsV1alpha1Publisher>The publisher of this claim review.
review_date: Option<DateTime<Utc>>The date the claim was reviewed.
textual_rating: Option<String>Textual rating. For instance, “Mostly false”.
title: Option<String>The title of this claim review, if it can be determined.
url: Option<String>The URL of this claim review.