GoogleFactcheckingFactchecktoolsV1alpha1ClaimReviewMarkup

Struct GoogleFactcheckingFactchecktoolsV1alpha1ClaimReviewMarkup 

pub struct GoogleFactcheckingFactchecktoolsV1alpha1ClaimReviewMarkup {
    pub claim_appearances: Option<Vec<String>>,
    pub claim_author: Option<GoogleFactcheckingFactchecktoolsV1alpha1ClaimAuthor>,
    pub claim_date: Option<String>,
    pub claim_first_appearance: Option<String>,
    pub claim_location: Option<String>,
    pub claim_reviewed: Option<String>,
    pub rating: Option<GoogleFactcheckingFactchecktoolsV1alpha1ClaimRating>,
    pub url: Option<String>,
}
Fields for an individual ClaimReview element. Except for sub-messages that group fields together, each of these fields correspond those in https://schema.org/ClaimReview. We list the precise mapping for each field.

This type is not used in any activity, and only used as part of another schema.

Fields

claim_appearances: Option<Vec<String>>

A list of links to works in which this claim appears, aside from the one specified in claim_first_appearance. Corresponds to ClaimReview.itemReviewed[@type=Claim].appearance.url.

claim_author: Option<GoogleFactcheckingFactchecktoolsV1alpha1ClaimAuthor>

Info about the author of this claim.

claim_date: Option<String>

The date when the claim was made or entered public discourse. Corresponds to ClaimReview.itemReviewed.datePublished.

claim_first_appearance: Option<String>

A link to a work in which this claim first appears. Corresponds to ClaimReview.itemReviewed[@type=Claim].firstAppearance.url.

claim_location: Option<String>

The location where this claim was made. Corresponds to ClaimReview.itemReviewed.name.

claim_reviewed: Option<String>

A short summary of the claim being evaluated. Corresponds to ClaimReview.claimReviewed.

rating: Option<GoogleFactcheckingFactchecktoolsV1alpha1ClaimRating>

Info about the rating of this claim review.

url: Option<String>

This field is optional, and will default to the page URL. We provide this field to allow you the override the default value, but the only permitted override is the page URL plus an optional anchor link (“page jump”). Corresponds to ClaimReview.url