pub struct GoogleFactcheckingFactchecktoolsV1alpha1ListClaimReviewMarkupPagesResponse {
pub claim_review_markup_pages: Option<Vec<GoogleFactcheckingFactchecktoolsV1alpha1ClaimReviewMarkupPage>>,
pub next_page_token: Option<String>,
}Expand description
Response from listing ClaimReview markup.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list pages (response)
Fields
claim_review_markup_pages: Option<Vec<GoogleFactcheckingFactchecktoolsV1alpha1ClaimReviewMarkupPage>>The result list of pages of ClaimReview markup.
next_page_token: Option<String>The next pagination token in the Search response. It should be used as the page_token for the following request. An empty value means no more results.