pub struct GoogleFactcheckingFactchecktoolsV1alpha1Publisher {
pub name: Option<String>,
pub site: Option<String>,
}Expand description
Information about the publisher.
This type is not used in any activity, and only used as part of another schema.
Fields
name: Option<String>The name of this publisher. For instance, “Awesome Fact Checks”.
site: Option<String>Host-level site name, without the protocol or “www” prefix. For instance, “awesomefactchecks.com”. This value of this field is based purely on the claim review URL.