pub struct GoogleFactcheckingFactchecktoolsV1alpha1FactCheckedClaimSearchResponse {
pub claims: Option<Vec<GoogleFactcheckingFactchecktoolsV1alpha1Claim>>,
pub next_page_token: Option<String>,
}Expand description
Response from searching fact-checked claims.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- search claims (response)
Fields
claims: Option<Vec<GoogleFactcheckingFactchecktoolsV1alpha1Claim>>The list of claims and all of their associated information.
next_page_token: Option<String>The next pagination token in the Search response. It should be used as the page_token for the following request. An empty value means no more results.